@@ -13,14 +13,14 @@
  *
  * You should have received a copy of the GNU Lesser General
  * Public License along with this library; if not, see
- * <http://www.gnu.org/licenses/>.
+ * <https://www.gnu.org/licenses/>.
  */
 
 #ifndef _BABL_MACROS_H
 #define _BABL_MACROS_H
 
-#ifndef BABL_INSIDE_BABL_H
-#error "babl-version.h must not be included directly, include babl.h instead."
+#if !defined(BABL_INSIDE_BABL_H) && !defined(BABL_IS_BEING_COMPILED)
+#error "babl-macros.h must not be included directly, include babl.h instead."
 #endif
 
 
